import type { NextPage } from "next";

import AboutMe from "../components/AboutMe";
import Services from "../components/Services";
import Contact from "../components/Contact";
import FullStory from "../components/FullStory";
import { NextSeo } from "next-seo";
import Head from "next/head";

const Home: NextPage = () => {
	return (
		<>
			<Head>
				<meta name="viewport" content="width=device-width, initial-scale=1.0" />
			</Head>
			<NextSeo
				title="Roman Developer"
				description="Primárně se zaměřuji na vývoj frontendů webových aplikací. Jsem schopný dělat vývoj i backedy webových aplikací. Mimo vývoj se ve volném čase věnuji údržbě vlastního serveru."
				canonical="https://www.romanjaros.cz"
				openGraph={{
					url: "https://www.romanjaros.cz",
					type: "websites",
					title: "Roman Jaroš, Developer",
					description:
						"Portfolio web frontent and backend vývojáře Roman Jaroš",
					site_name: "Roman Developer",
					locale: "Czech Republic",
					images: [
						{
							url: "https://www.romanjaros.cz/icon.svg",
							alt: "Roman Developer",
						},
					],
				}}
				additionalLinkTags={[
					{
						rel: "icon",
						href: "https://www.romanjaros.cz/favicon.ico",
					},
					{
						rel: "apple-touch-icon",
						href: "https://www.romanjaros.cz/icon.svg",
						sizes: "76x76",
					},
				]}
			/>
			<div className="mx-auto w-full md:w-4/5">
				<header className="mytitle text-3xl lg:text-6xl justify-center text-center mb-20">
					<span className="mytitle-left">{"<"}</span>
					<h1>
						<span className="mytitle-left">Roman</span>
						<span className="mytitle-right">Developer</span>
					</h1>
					<span className="mytitle-left">&nbsp;{"/>"}</span>
				</header>
				<AboutMe />
				<Services />
				<Contact />
				<FullStory />
			</div>
		</>
	);
};

export default Home;
